==> dada-6_8_0.tar: dada/extras/packages/core5_filemanager/scripts/languages/en.js <==
{
    "ALLOWED_FILE_TYPE": "Only following files are allowed : ", 
    "AUTHORIZATION_REQUIRED": "You are not authorized to use filemanager.", 
    "DIRECTORY_ALREADY_EXISTS": "The directory '%s' already exists.", 
    "DIRECTORY_NOT_EXIST": "The directory %s does not exist.", 
    "DISALLOWED_FILE_TYPE": "Following files are not allowed : ", 
    "ERROR_RENAMING_DIRECTORY": "Error while renaming the directory %s to %s.", 
    "ERROR_RENAMING_FILE": "Error while renaming the file %s to %s.", 
    "FILE_ALREADY_EXISTS": "The file '%s' already exists.", 
    "FILE_DOES_NOT_EXIST": "The file %s does not exist.", 
    "INVALID_ACTION": "Invalid action.", 
    "INVALID_DIRECTORY_OR_FILE": "Invalid directory or file.", 
    "INVALID_FILE_TYPE": "File upload is not allowed.", 
    "INVALID_FILE_UPLOAD": "Invalid file upload.", 
    "INVALID_VAR": "Invalid var %s.", 
    "LANGUAGE_FILE_NOT_FOUND": "Language file not found.", 
    "MODE_ERROR": "Mode error.", 
    "UNABLE_TO_CREATE_DIRECTORY": "Unable to create the directory %s.", 
    "UNABLE_TO_OPEN_DIRECTORY": "Unable to open the directory %s.", 
    "UPLOAD_FILES_SMALLER_THAN": "Please upload only files smaller than %s.", 
    "UPLOAD_IMAGES_ONLY": "Please upload only images, no other files are supported.", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "Please upload only images of type JPEG, GIF or PNG.", 
    "browse": "Browse...", 
    "bytes": " bytes", 
    "cancel": "Cancel", 
    "confirmation_delete": "Are you sure you wish to delete this file?", 
    "could_not_retrieve_folder": "Could not retrieve folder contents.", 
    "create_folder": "Create Folder", 
    "created": "Created", 
    "current_folder": "Current folder: ", 
    "default_foldername": "My folder", 
    "del": "Delete", 
    "dimensions": "Dimensions", 
    "download": "Download", 
    "fck_select_integration": "The 'Select' function is only used for integration with FCKEditor.", 
    "file_size_limit": "The file size limit is : ", 
    "file_too_big": "The file is too big.", 
    "gb": "gb", 
    "grid_view": "Switch to grid view.", 
    "kb": "kb", 
    "list_view": "Switch to list view.", 
    "loading_data": "Transferring data ...", 
    "mb": "mb", 
    "modified": "Modified", 
    "name": "Name", 
    "new_filename": "Enter a new name for the file", 
    "new_folder": "New folder", 
    "no": "No", 
    "no_foldername": "No folder name was provided.", 
    "parentfolder": "Parent folder", 
    "prompt_foldername": "Enter the name of the new folder", 
    "rename": "Rename", 
    "search": "Search", 
    "search_reset": "Reset", 
    "select": "Select", 
    "select_from_left": "Select an item from the left.", 
    "size": "Size", 
    "successful_added_file": "New file added successfully.", 
    "successful_added_folder": "New folder added successfully.", 
    "successful_delete": "Delete successful.", 
    "successful_rename": "Rename successful.", 
    "upload": "Upload", 
    "yes": "Yes"
}

==> dada-11_1_2.tar: dada/extras/packages/core5_filemanager/scripts/languages/en.js <==
{
    "ALLOWED_FILE_TYPE": "Only following files are allowed : ", 
    "AUTHORIZATION_REQUIRED": "You are not authorized to use filemanager.", 
    "DIRECTORY_ALREADY_EXISTS": "The directory '%s' already exists.", 
    "DIRECTORY_NOT_EXIST": "The directory %s does not exist.", 
    "DISALLOWED_FILE_TYPE": "Following files are not allowed : ", 
    "ERROR_CREATING_ZIP": "Error creating Zip archive",
    "ERROR_OPENING_FILE": "Error opening file.",
    "ERROR_RENAMING_DIRECTORY": "Error while renaming the directory %s to %s.", 
    "ERROR_RENAMING_FILE": "Error while renaming the file %s to %s.",
    "ERROR_REPLACING_FILE": "Please, provide a file having the following extension :", 
    "ERROR_SAVING_FILE": "Error saving file.",
    "ERROR_UPLOADING_FILE": "Error uploading file.", 
    "ERROR_WRITING_PERM": "You don't have write permissions on that file.",
    "FILE_ALREADY_EXISTS": "The file '%s' already exists.", 
    "FILE_DOES_NOT_EXIST": "The file %s does not exist.", 
    "INVALID_ACTION": "Invalid action.", 
    "INVALID_DIRECTORY_OR_FILE": "Invalid directory or file.", 
    "INVALID_FILE_TYPE": "File type is not allowed.", 
    "INVALID_FILE_UPLOAD": "Invalid file upload.", 
    "INVALID_VAR": "Invalid var %s.", 
    "LANGUAGE_FILE_NOT_FOUND": "Language file not found.", 
    "MODE_ERROR": "Mode error.", 
    "NOT_ALLOWED": "You are not allowed to process this action",
    "NOT_ALLOWED_SYSTEM": "System permissions do not allow you to perform this action", 
    "UNABLE_TO_CREATE_DIRECTORY": "Unable to create the directory %s.", 
    "UNABLE_TO_OPEN_DIRECTORY": "Unable to open the directory %s.", 
    "UPLOAD_FILES_SMALLER_THAN": "Please upload only files smaller than %s.", 
    "UPLOAD_IMAGES_ONLY": "Please upload only images, no other files are supported.", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "Please upload only images of type JPEG, GIF or PNG.", 
    "browse": "Browse...", 
    "bytes": " bytes", 
    "cancel": "Cancel", 
    "close": "Close",
    "confirmation_delete": "Are you sure you wish to delete this file?", 
    "copied": "URL copied !", 
    "copy_to_clipboard": "Copy URL to Clipboard",
    "could_not_retrieve_folder": "Could not retrieve folder contents.", 
    "create_folder": "Create Folder", 
    "created": "Created", 
    "current_folder": "Current folder: ", 
    "default_foldername": "My folder", 
    "del": "Delete",
    "dimensions": "Dimensions", 
    "download": "Download", 
    "dz_dictDefaultMessage": "Drop files here to upload",
    "dz_dictFallbackMessage": "Your browser does not support drag'n'drop file uploads.",
    "dz_dictMaxFilesExceeded": "Only %s simultaneous uploads are allowed.",
    "dz_dictInvalidFileType": "You can't upload files of this type.",
    "edit": "Edit file", 
    "fck_select_integration": "The 'Select' function is only used for integration with FCKEditor.", 
    "file_size_limit": "The file size limit (per file) is ", 
    "file_too_big": "The file is too big.", 
    "gb": "gb", 
    "grid_view": "Switch to grid view.", 
    "help_move": "The use of '../' is forbidden. You can access root folder by using '/'.",
    "items": "items",
    "kb": "kb", 
    "list_view": "Switch to list view.", 
    "loading_data": "Transferring data ...", 
    "mb": "mb", 
    "modified": "Modified", 
    "move": "Move to ...",
    "name": "Name",
    "new_filename": "Enter a new name for the file", 
    "new_folder": "New folder", 
    "no": "No", 
    "no_foldername": "No folder name was provided.", 
    "parentfolder": "Parent folder", 
    "prompt_foldername": "Enter the name of the new folder", 
    "quit_editor": "Quit editor",
    "rename": "Rename", 
    "replace": "Replace file",
    "save": "Save",
    "search": "Search", 
    "search_reset": "Reset", 
    "select": "Select", 
    "select_from_left": "Select an item from the left.", 
    "size": "Size", 
    "successful_added_file": "New file(s) added successfully.", 
    "successful_added_folder": "New folder added successfully.", 
    "successful_delete": "Delete successful.", 
    "successful_moved": "Move successful.",
    "successful_replace": "File replacement successful.", 
    "successful_rename": "Rename successful.",
    "successful_edit": "Content update successful.",
    "support_fm": "Filemanager is a free software, please support !", 
    "upload": "Upload", 
    "version": "version",
    "yes": "Yes"
}
